clear all;
close all;

addpath('./CTB-master');

% Read s-parameter file of commercial element

sparam_file = sprintf("R14S101_SNT.s2p"); % 100 pf shunt capacitor
sparam_file_escaped = strrep(sparam_file,"_","\\_");

[type,freq,data,ref,comment]=read_touchstone(sparam_file);

a=s2a(data); % convert to s-parameter

zin = 1./a(2,1,:) + a(1,2,:);

figure(1);
semilogx(freq,squeeze(abs(zin)),sprintf(";abs(zin);"),"linewidth", 2.5);
hold on;
semilogx(freq,squeeze(real(zin)),sprintf(";Re(zin);"),"linewidth", 1.5);
semilogx(freq,squeeze(imag(zin)),sprintf(";Im(zin);"),"linewidth", 1.5);
semilogx(freq,-1.0./(2*pi*freq*100e-12),sprintf(";Im(Ideal 100 pf capacitor);"),"linewidth", 1.5);
hold off;
title(sprintf("Input Impedance of S-parameter Input file %s\nJohanson 100 pf capacitor",sparam_file_escaped));
xlabel("Frequency (Hz)");
ylabel("Impedance (ohms)");
xtick = get (gca, "xtick"); 
xticklabel = strsplit (sprintf ("%.0e\n", xtick), "\n", true); 
set (gca, "xticklabel", xtick);

set(gca,"fontsize",14);
set(legend,"location","northwest");
ylim([-50,50]);
grid on;
grid minor on;

pause(3);

tf = 1./a(1,1,:);

figure(2);
semilogx(freq,20*log10(squeeze(abs(tf))),sprintf(";abs(tf);"),"linewidth", 2.5);
hold on;
% semilogx(freq,20*log10(squeeze(real(tf))),sprintf(";Re(tf);"),"linewidth", 1.5);
% semilogx(freq,20*log10(squeeze(imag(tf))),sprintf(";Im(tf);"),"linewidth", 1.5);
hold off;
title(sprintf("Transfer Function of S-parameter Input file %s\nJohanson 100 pf capacitor",sparam_file_escaped));
xlabel("Frequency (Hz)");
ylabel("Transfer Function (dB)");
set(gca,"fontsize",14);
% ylim([-50,150]);
grid on;
grid minor on;
xtick = get (gca, "xtick"); 
xticklabel = strsplit (sprintf ("%.0e\n", xtick), "\n", true); 
set (gca, "xticklabel", xtick);

pause(3);

% PLot S11 and S21

figure(3)
plot(freq,(squeeze(abs(data(1,1,:)))),sprintf(";S11;"),"linewidth", 1.5);
hold on;
grid on;
grid minor on;
plot(freq,(squeeze(abs(data(2,1,:)))),sprintf("r--;S21;"),"linewidth", 1.5);
set(gca,"fontsize",14);
hold off;
title(sprintf("S11 and S21 of S-parameter Input file %s\nJohanson 100 pf capacitor",sparam_file_escaped));
xlabel("Frequency (Hz)");
ylabel("Magnitude");
xtick = get (gca, "xtick"); 
xticklabel = strsplit (sprintf ("%.0e\n", xtick), "\n", true); 
set (gca, "xticklabel", xtick);

pause(3);


