clear all;
close all;

addpath('./CTB-master');
% create ABCD matrix of a series L, shunt R and shunt C
% of value L1, R1, and C1

R1 = 50.0;
L1 = 40e-09;
C1 = 100e-12;

f = logspace(3,9,20*6); % frequency vector
a = a_shunt((1.0/R1)*ones(size(f)));
a = a_mul(a,a_shunt(2.0*j*pi*f*C1));

al = a_series(2.0*j*pi*f*L1);

a = a_mul(a,al);

% Create same network using T function

at = a_T(2.0*j*pi*f*L1,zeros(size(f)),R1./(1 + 2.0*j*pi*f*C1*R1));

s = a2s(a); % convert to s-parameter

fshunt = 1/(2*pi*R1*C1);

% Plot S11 and S21

figure(1)
plot(f,(squeeze(abs(s(1,1,:)))),sprintf(";S11;"),"linewidth", 1.5);
hold on;
grid on;
grid minor on;
plot(f,(squeeze(abs(s(2,1,:)))),sprintf("r--;S21;"),"linewidth", 1.5);
set(gca,"fontsize",14);
hold off;
title(sprintf("S11 and S21 of Network with L1 with Shunt R1 and C1 Elements\nR1 = %.1f ohms, C1 = %.1f pf (%.2f MHz), L1 = %.1f nH",R1,C1/1e-12,fshunt/1e6,L1/1e-09));
xlabel("Frequency (Hz)");
ylabel("Magnitude");

pause(3);

% Compute input impedance from ABCD matrix
% Plot magnitude and real and imaginary parts of input impedance

z = 1./a(2,1,:) + a(1,2,:);

figure(2);
loglog(f,squeeze(abs(z)),sprintf(";abs(z);"),"linewidth", 1.5);
hold on;
loglog(f,squeeze(real(z)),sprintf(";Re(z);"),"linewidth", 1.5);
loglog(f,squeeze(imag(z)),sprintf(";Im(z);"),"linewidth", 1.5);
hold off;
title(sprintf("Input Impedance of L1 with Shunt R1 and C1 Elements\nR1 = %.1f ohms, C1 = %.1f pf (%.2f MHz), L1 = %.1f nH",R1,C1/1e-12,fshunt/1e6,L1/1e-09));
xlabel("Frequency (Hz)");
ylabel("Impedance (ohms)");
set(gca,"fontsize",14);
grid on;
grid minor on;

pause(3);

% Perform same analysis using ABCD matrix defined with T-network

zt = 1./at(2,1,:) + at(1,2,:);
figure(3);
loglog(f,squeeze(abs(zt)),sprintf(";abs(zt);"),"linewidth", 1.5);
hold on;
loglog(f,squeeze(real(zt)),sprintf(";Re(zt);"),"linewidth", 1.5);
loglog(f,squeeze(imag(zt)),sprintf(";Im(zt);"),"linewidth", 1.5);
hold off;
title(sprintf("Input Impedance of L1 with Shunt R1 and C1 Elements\nR1 = %.1f ohms, C1 = %.1f pf (%.2f MHz), L1 = %.1f nH",R1,C1/1e-12,fshunt/1e6,L1/1e-09));
xlabel("Frequency (Hz)");
ylabel("Impedance (ohms)");
set(gca,"fontsize",14);
grid on;
grid minor on;

pause(3);

figure(4);
semilogx(f,squeeze(abs(zt)),sprintf(";abs(zt);"),"linewidth", 2.5);
hold on;
semilogx(f,squeeze(real(zt)),sprintf(";Re(zt);"),"linewidth", 1.5);
semilogx(f,squeeze(imag(zt)),sprintf(";Im(zt);"),"linewidth", 1.5);
hold off;
title(sprintf("Input Impedance of L1 with Shunt R1 and C1 Elements\nR1 = %.1f ohms, C1 = %.1f pf (%.2f MHz), L1 = %.1f nH",R1,C1/1e-12,fshunt/1e6,L1/1e-09));
xlabel("Frequency (Hz)");
ylabel("Impedance (ohms)");
set(gca,"fontsize",14);
ylim([-50,150]);
grid on;
grid minor on;

pause(3);